@@ -1,13 +1,14 @@
-Bchronproxyplot <- function (Bchrondata, proxy, title = NULL, xlabel = "Age (k cal yrs BP)",  ylabel = "Proxy", num = 1000, col = "blue",meancol="red", transp=0.1,...) {
+Bchronproxyplot <-
+function (Bchrondata, proxy, title = NULL, xlabel = "Age (k cal yrs BP)",  ylabel = "Proxy", num = 1000, col = "blue",meancol="red", transp=0.1,...) {
 
 # Read in all chronologies  
 Bchrondata$chrons <- as.matrix(read.table(Bchrondata$chronsfile))
 Bchrondata$ranges <- read.table(Bchrondata$rangesfile,header=TRUE)
-
+  
 # Now produce plot of lines
 xlimits <- c(min(Bchrondata$ranges[, 2]), max(Bchrondata$ranges[,4]))
 ylimits <- c(min(proxy), max(proxy))
-dev.new(...)
+#dev.new(...)
 plot(1, 1, type = "n", xlim = xlimits, ylim = ylimits, main = title, xlab = xlabel, ylab = ylabel, las = 1)
 grid()
 
